// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.
package models

import (
	"leit.com/aps_engine/db"
	"errors"
	"xorm.io/core"
	"time"
)

type Weekmodel struct {
	Plantnr     int       `json:"PlantNr" xorm:"not null pk INT(4)"`
	Weekmodelnr int       `json:"WeekModelNr" xorm:"not null pk INT(4)"`
	Datefrom    int       `json:"DateFrom" xorm:"not null INT(4)"`
	Descr       string    `json:"Descr" xorm:"not null NVARCHAR(200)"`
	Abrev       string    `json:"Abrev" xorm:"not null NVARCHAR(20)"`
	Ctrltoggle  int       `json:"CtrlToggle" xorm:"not null BIT(1)"`
	Loopdays    int       `json:"LoopDays" xorm:"not null INT(4)"`
	Lastmodify  time.Time `json:"LastModify" xorm:"DATETIME(8)"`
	Lastuser    string    `json:"LastUser" xorm:"not null NVARCHAR(40)"`
	Createtime  time.Time `json:"CreateTime" xorm:"DATETIME(8)"`
	Itemlst 	[]Daymodel `json:"itemlst" xorm:"-"`
}

/******数据表名******/
func (t *Weekmodel) TableName() string {
	return "Weekmodel"
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据添加
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *Weekmodel) Add() error {
	e := db.Eloquent.Master()
	count := new(Weekmodel)
	affw, err := e.Table(t.TableName()).ID(core.PK{t.Plantnr, t.Weekmodelnr}).Count(count)
	if err != nil {
		return err
	}
	if affw > 0 {
		return errors.New("数据已经存在！")
	}
	_, err = e.Table(t.TableName()).Insert(t)

	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据删除
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *Weekmodel) Del() bool {
	e := db.Eloquent.Master()
	_, err := e.ID(core.PK{t.Plantnr, t.Weekmodelnr}).Delete(&Weekmodel{})
	if err != nil {
		return false
	}
	return true
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据修改
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *Weekmodel) Update() error {
	e := db.Eloquent.Master()
	_, err := e.ID(core.PK{t.Plantnr, t.Weekmodelnr}).Update(t)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据查找
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *Weekmodel) SelectOne() (Weekmodel, error) {
	e := db.Eloquent.Master()
	var data Weekmodel
	_, err := e.ID(core.PK{t.Plantnr, t.Weekmodelnr}).Get(&data)
	if err != nil {
		return data, err
	}
	return data, nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据查找
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *Weekmodel) SelectAll() (datalst []Weekmodel, err error) {
	var i	int

	e := db.Eloquent.Master()
	if err = e.Table(t.TableName()).Where("PlantNr = ?",t.Plantnr).OrderBy("WeekModelNr").Find(&datalst);err != nil {
		return
	}
	for i = 0; i < len(datalst); i++ {
		if err = e.Table("WeekModelLst").Where("PlantNr = ? and WeekModelNr = ?", datalst[i].Plantnr,
			datalst[i].Weekmodelnr).OrderBy("WorkDate").Find(&datalst[i].Itemlst); err != nil {
			return
		}
	}
	return
}
