package service

import (
	"strconv"
	"time"
)

// 订单工序对象
type OperationSrv struct{
	OperationNr 		int					// 工序号
	SplitNr 			int 				// 工序拆分号
	OrderId				string				// 订单号
	Status 				int					// 工序状态
	WorkPlaceGrpNr		int 				// 对应资源组号
	ToolGrpNr			int					// 对应工具组号
	PlanQty 			float32
	PlanDuration 		time.Duration		// 计划工时
	SetupStartTime		time.Time			// 换型开始
	SetupEndTime 		time.Time			// 换型结束
	PlanStartTime		time.Time			// 计划生产开始
	PlanEndTime 		time.Time			// 计划生产结束
	PostStartTime 		time.Time			// 计划后处理开始
	PostEndTime			time.Time			// 计划后处理结束
	PlanWorkPlaceNr		int 				// 计划工位号
	PlanToolNr 			int
	PrevOpDict			map[string]OperationRelSrv	// 前工序
	NextOpDict			map[string]OperationRelSrv	// 后工序
	AttributeDict		map[int]OpAttribute			// 工序分配的属性
	ToolDemandDict		map[int]OpToolDemand		// 工序的工具需求
	ArtChangeDict		map[string]OpArticleChange	// 工序的物料变化
	SkillDemandDict 	map[int]OpSkillDemand		// 工序的技能需求
	SecResDemandDict	map[int]OpSecResourceDemand	// 工序的次要资源需求
}

// 工序分配的属性，用于匹配计划设备
type OpAttribute struct {
	AttributeNr	int

}

// 工序的工具需求
type OpToolDemand struct {
	ToolNr		int
	ReqQty		int
	Operation 	*OperationSrv
}
// 工序的物料需求
type OpArticleChange struct {
	ArtId 		string
	ChangeMode	int
	ChangeQty	float64
	Operation 	*OperationSrv
}
// 工序的技能需求
type OpSkillDemand struct {
	SkillNr 	int
	ReqQty		int
	Operation   *OperationSrv
}
// 工序的次要资源需求
type OpSecResourceDemand struct {
	ResourceNr	int
	ReqQty		int
	Operation   *OperationSrv
}

// 获取工序键值：工序号-工序拆分号
func(ops *OperationSrv)GetKey()(string){
	return strconv.Itoa(ops.OperationNr) + "-" + strconv.Itoa(ops.SplitNr)
}

// 初始化
func(ops *OperationSrv)Init(){
	ops.PrevOpDict 	= make(map[string]OperationRelSrv)
	ops.NextOpDict	= make(map[string]OperationRelSrv)
}

// 获取任务计划开始事件
func(ops *OperationSrv)GetPlanStartEvent(t time.Time)(SchedEvent){
	var(
		opet OperationEvent
	)

	opet = OperationEvent{TriggerTime: t, EventType: EVENT_OBJ_OPTASK, Event: EVENT_TASK_PLANBEG}
	opet.OrderId 		= ops.OrderId
	opet.OperationNr	= ops.OperationNr
	opet.SplitNr		= ops.SplitNr

	return SchedEvent(opet)
}

// 获取任务计划结束事件
func(ops *OperationSrv)GetPlanEndEvent(t time.Time)(SchedEvent){
	var(
		opet OperationEvent
	)

	opet = OperationEvent{TriggerTime: t, EventType: EVENT_OBJ_OPTASK, Event: EVENT_TASK_PLANEND}
	opet.OrderId 		= ops.OrderId
	opet.OperationNr	= ops.OperationNr
	opet.SplitNr		= ops.SplitNr

	return SchedEvent(opet)
}
